==> lightpdf_aipdf_mcp-0.1.100-py3-none-any.whl: lightpdf_aipdf_mcp/create_pdf.py <==
"""根据LaTeX内容创建PDF文件的接口（未实现具体逻辑）"""
from typing import Optional
import os
import uuid
from .common import Logger, FileHandler
from .editor import Editor, EditResult, EditType

async def create_pdf_from_latex(latex_content: str, output_path: Optional[str] = None, logger: Optional[Logger] = None):
    """
    根据LaTeX内容创建PDF文件。

    参数：
        latex_content (str): LaTeX源内容。
        output_path (Optional[str]): 可选，输出PDF文件路径。
        logger (Optional[Logger]): 日志对象。
    返回：
        dict: 包含生成结果的信息（如成功与否、PDF路径、错误信息等）。
    """
    tex_path = None
    try:
        # 1. 保存latex_content为本地.tex文件
        try:
            temp_dir = "./tmp"
            os.makedirs(temp_dir, exist_ok=True)
            tex_filename = f"latex_{uuid.uuid4().hex}.tex"
            tex_path = os.path.join(temp_dir, tex_filename)
            with open(tex_path, "w", encoding="utf-8") as f:
                f.write(latex_content)
        except Exception as e:
            return EditResult(
                error_message=f"保存LaTeX内容失败: {e}"
            )

        # 2. 调用Editor.edit_pdf并传递oss://tex2pdf参数生成PDF
        try:
            # 构造Logger和FileHandler
            file_handler = FileHandler(logger)
            editor = Editor(logger, file_handler)

            # extra_params按txt转pdf方式
            extra_params = {"pages": '[{"url": "oss://tex2pdf", "oss_file": ""}]'}

            # 这里original_name可用tex_filename
            result: EditResult = await editor.edit_pdf(tex_path, edit_type=EditType.EDIT, extra_params=extra_params, original_name=tex_filename)
            # 3. 返回结果
            return result
        except Exception as e:
            return EditResult(
                error_message=f"PDF生成失败: {e}"
            )
    finally:
        if tex_path and os.path.exists(tex_path):
            try:
                os.remove(tex_path)
            except Exception:
                pass

==> lightpdf_aipdf_mcp-0.1.103-py3-none-any.whl: lightpdf_aipdf_mcp/create_pdf.py <==
"""根据LaTeX内容创建PDF文件的接口（未实现具体逻辑）"""
from typing import Optional
import os
import uuid
from .common import Logger, FileHandler
from .editor import Editor, EditResult, EditType

async def create_pdf_from_latex(latex_content: str, output_path: Optional[str] = None, logger: Optional[Logger] = None, original_name: Optional[str] = None):
    """
    根据LaTeX内容创建PDF文件。

    参数：
        latex_content (str): LaTeX源内容。
        output_path (Optional[str]): 可选，输出PDF文件路径。
        logger (Optional[Logger]): 日志对象。
        original_name (Optional[str]): 可选，原始文件名。
    返回：
        dict: 包含生成结果的信息（如成功与否、PDF路径、错误信息等）。
    """
    tex_path = None
    try:
        # 1. 保存latex_content为本地.tex文件
        try:
            temp_dir = "./tmp"
            os.makedirs(temp_dir, exist_ok=True)
            tex_filename = f"latex_{uuid.uuid4().hex}.tex"
            tex_path = os.path.join(temp_dir, tex_filename)
            with open(tex_path, "w", encoding="utf-8") as f:
                f.write(latex_content)
        except Exception as e:
            return EditResult(
                error_message=f"保存LaTeX内容失败: {e}"
            )

        # 2. 调用Editor.edit_pdf并传递oss://tex2pdf参数生成PDF
        try:
            # 构造Logger和FileHandler
            file_handler = FileHandler(logger)
            editor = Editor(logger, file_handler)

            # extra_params按txt转pdf方式
            extra_params = {"pages": '[{"url": "oss://tex2pdf", "oss_file": ""}]'}

            # original_name优先用传入的参数，否则用tex_filename
            result: EditResult = await editor.edit_pdf(tex_path, edit_type=EditType.EDIT, extra_params=extra_params, original_name=original_name or tex_filename)
            # 3. 返回结果
            return result
        except Exception as e:
            return EditResult(
                error_message=f"PDF生成失败: {e}"
            )
    finally:
        if tex_path and os.path.exists(tex_path):
            try:
                os.remove(tex_path)
            except Exception:
                pass
